#[repr(transparent)]pub struct SgiCtrl(pub u32);Expand description
SGI Control register.
Tuple Fields
0: u32Implementations
Sourceimpl SgiCtrl
impl SgiCtrl
Sourcepub const fn set_decrypt(&mut self, val: Decrypt)
pub const fn set_decrypt(&mut self, val: Decrypt)
Sets Cipher direction(AES and DES).
Sourcepub const fn set_aeskeysz(&mut self, val: Aeskeysz)
pub const fn set_aeskeysz(&mut self, val: Aeskeysz)
Sets AES key size.
Sourcepub const fn set_crypto_op(&mut self, val: CryptoOp)
pub const fn set_crypto_op(&mut self, val: CryptoOp)
Sets ‘Crypto Operation’ type.
Sourcepub const fn set_outsel(&mut self, val: Outsel)
pub const fn set_outsel(&mut self, val: Outsel)
no description available.
Sourcepub const fn datout_res(&self) -> DatoutRes
pub const fn datout_res(&self) -> DatoutRes
Kernels data out options.
Sourcepub const fn set_datout_res(&mut self, val: DatoutRes)
pub const fn set_datout_res(&mut self, val: DatoutRes)
Kernels data out options.
Sourcepub const fn set_aes_en(&mut self, val: bool)
pub const fn set_aes_en(&mut self, val: bool)
AES Kernel Enable.
Sourcepub const fn set_des_en(&mut self, val: bool)
pub const fn set_des_en(&mut self, val: bool)
DES Kernel Enable.
Sourcepub const fn set_gcm_en(&mut self, val: bool)
pub const fn set_gcm_en(&mut self, val: bool)
GFMUL Kernel Enable.
Sourcepub const fn set_prng_en(&mut self, val: bool)
pub const fn set_prng_en(&mut self, val: bool)
PRNG Enable (only if SGI has internal PRNG).
Sourcepub const fn set_inkeysel(&mut self, val: u8)
pub const fn set_inkeysel(&mut self, val: u8)
Input key selection.
Sourcepub const fn set_tdeskey(&mut self, val: Tdeskey)
pub const fn set_tdeskey(&mut self, val: Tdeskey)
Triple-DES Key Configuration.
Sourcepub const fn aes_no_kl(&self) -> AesNoKl
pub const fn aes_no_kl(&self) -> AesNoKl
AES No decryption key scheduleThis bit is only supported for select configurations of the SGI.
Sourcepub const fn set_aes_no_kl(&mut self, val: AesNoKl)
pub const fn set_aes_no_kl(&mut self, val: AesNoKl)
AES No decryption key scheduleThis bit is only supported for select configurations of the SGI.
Sourcepub const fn set_aes_sel(&mut self, val: AesSel)
pub const fn set_aes_sel(&mut self, val: AesSel)
AES Dual Selection.