#[repr(transparent)]pub struct SgiStatus(pub u32);Expand description
Status register.
Tuple Fields
0: u32Implementations
Sourceimpl SgiStatus
impl SgiStatus
Sourcepub const fn busy(&self) -> bool
pub const fn busy(&self) -> bool
Combined busy flag that remains high until end of calculation.
Sourcepub const fn set_busy(&mut self, val: bool)
pub const fn set_busy(&mut self, val: bool)
Combined busy flag that remains high until end of calculation.
Sourcepub const fn set_prng_rdy(&mut self, val: bool)
pub const fn set_prng_rdy(&mut self, val: bool)
prng is ready after boot-up-phase.
Sourcepub const fn set_sha2_busy(&mut self, val: bool)
pub const fn set_sha2_busy(&mut self, val: bool)
SHA2 is busy.
Sourcepub const fn sha_fifo_full(&self) -> bool
pub const fn sha_fifo_full(&self) -> bool
SHA FIFO is full(operates in SHA AUTO mode).
Sourcepub const fn set_sha_fifo_full(&mut self, val: bool)
pub const fn set_sha_fifo_full(&mut self, val: bool)
SHA FIFO is full(operates in SHA AUTO mode).
Sourcepub const fn sha_fifo_level(&self) -> u8
pub const fn sha_fifo_level(&self) -> u8
SHA FIFO level.
Sourcepub const fn set_sha_fifo_level(&mut self, val: u8)
pub const fn set_sha_fifo_level(&mut self, val: u8)
SHA FIFO level.
Sourcepub const fn set_sha_error(&mut self, val: bool)
pub const fn set_sha_error(&mut self, val: bool)
SHA ERROR.
Sourcepub const fn key_read_err(&self) -> bool
pub const fn key_read_err(&self) -> bool
KEY SFR READ ERROR, sticky, cleared only with reset or flush.
Sourcepub const fn set_key_read_err(&mut self, val: bool)
pub const fn set_key_read_err(&mut self, val: bool)
KEY SFR READ ERROR, sticky, cleared only with reset or flush.
Sourcepub const fn key_unwrap_err(&self) -> bool
pub const fn key_unwrap_err(&self) -> bool
KEY UNWRAP ERROR , sticky, cleared only with reset or flush.
Sourcepub const fn set_key_unwrap_err(&mut self, val: bool)
pub const fn set_key_unwrap_err(&mut self, val: bool)
KEY UNWRAP ERROR , sticky, cleared only with reset or flush.